===========
Django-Haul
===========


.. image:: https://img.shields.io/pypi/v/haul.svg
        :target: https://pypi.python.org/pypi/haul

.. image:: https://img.shields.io/travis/elements-storage/haul.svg
        :target: https://travis-ci.com/elements-storage/haul

.. image:: https://readthedocs.org/projects/haul/badge/?version=latest
        :target: https://haul.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Object import/export for Django


* Free software: MIT license
* Documentation: https://haul.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
